render_ansi

Function render_ansi 

pub fn render_ansi(
    source: &[u8],
    spans: &[StyledSpan],
) -> Result<String, RenderError>
Renders a source buffer and styled spans into a single ANSI string.

Errors

Returns an error when spans are out of bounds, unsorted, or overlapping.