Crate render_ansi

Crate render_ansi 

Structs

IncrementalRenderer
StreamLineRenderer
Incremental renderer for a single mutable line without terminal width assumptions.
StyledSpan

Enums

ColorMode
RenderError

Functions

highlight_lines_to_ansi_lines
Highlights line-oriented input and returns ANSI output per line.
highlight_lines_to_ansi_lines_with_highlighter
Highlights line-oriented input with a caller-provided highlighter.
highlight_lines_to_ansi_lines_with_highlighter_and_mode
Highlights line-oriented input with a caller-provided highlighter and color mode.
highlight_lines_to_ansi_lines_with_mode
Highlights line-oriented input and returns ANSI output per line using a color mode.
highlight_to_ansi
Highlights and renders a source buffer to ANSI output.
highlight_to_ansi_with_highlighter
Highlights and renders a source buffer using a caller-provided highlighter.
highlight_to_ansi_with_highlighter_and_mode
Highlights and renders a source buffer using a caller-provided highlighter and color mode.
highlight_to_ansi_with_mode
Highlights and renders a source buffer with an explicit ANSI color mode.
render_ansi
Renders a source buffer and styled spans into a single ANSI string.
render_ansi_lines
Renders a source buffer and styled spans into per-line ANSI strings.
render_ansi_lines_with_mode
Renders a source buffer and styled spans into per-line ANSI strings.
render_ansi_with_mode
Renders a source buffer and styled spans into a single ANSI string.
resolve_styled_spans
Resolves highlight spans into renderable spans by attaching theme styles.