Structs
- Incremental
Renderer - Stream
Line Renderer - Incremental renderer for a single mutable line without terminal width assumptions.
- Styled
Span
Enums
Functions
- highlight_
lines_ to_ ansi_ lines - Highlights line-oriented input and returns ANSI output per line.
- highlight_
lines_ to_ ansi_ lines_ with_ highlighter - Highlights line-oriented input with a caller-provided highlighter.
- highlight_
lines_ to_ ansi_ lines_ with_ highlighter_ and_ mode - Highlights line-oriented input with a caller-provided highlighter and color mode.
- highlight_
lines_ to_ ansi_ lines_ with_ mode - Highlights line-oriented input and returns ANSI output per line using a color mode.
- highlight_
to_ ansi - Highlights and renders a source buffer to ANSI output.
- highlight_
to_ ansi_ with_ highlighter - Highlights and renders a source buffer using a caller-provided highlighter.
- highlight_
to_ ansi_ with_ highlighter_ and_ mode - Highlights and renders a source buffer using a caller-provided highlighter and color mode.
- highlight_
to_ ansi_ with_ mode - Highlights and renders a source buffer with an explicit ANSI color mode.
- render_
ansi - Renders a source buffer and styled spans into a single ANSI string.
- render_
ansi_ lines - Renders a source buffer and styled spans into per-line ANSI strings.
- render_
ansi_ lines_ with_ mode - Renders a source buffer and styled spans into per-line ANSI strings.
- render_
ansi_ with_ mode - Renders a source buffer and styled spans into a single ANSI string.
- resolve_
styled_ spans - Resolves highlight spans into renderable spans by attaching theme styles.